window.Gleam.initSearch([{"doc":"glance","title":"glance","content":"# glance\n\n[![Package Version](https://img.shields.io/hexpm/v/glance)](https://hex.pm/packages/glance)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glance/)\n\nA Gleam source code parser, in Gleam!\n\nGlance attempts to be permissive with regards to what it will parse and so it is\nable to parse some code that the Gleam compiler will reject as invalid.\n\n## Usage\n\nAdd the package to your Gleam project:\n\n```sh\ngleam add glance\n```\n\nThen get parsing!\n\n```gleam\nimport glance\nimport gleam/io\n\nconst code = &quot;\n  pub type Cardinal {\n    North\n    East\n    South\n    West\n  }\n&quot;\n\npub fn main() {\n  let assert Ok(parsed) = glance.module(code)\n  io.debug(parsed.custom_types)\n}\n```\n\nThis program print this to the console:\n  \n```gleam\n[\n  Definition(\n    [],\n    CustomType(\n      name: &quot;Cardinal&quot;,\n      publicity: Public,\n      parameters: [],\n      variants: [\n        Variant(&quot;North&quot;, []),\n        Variant(&quot;East&quot;, []),\n        Variant(&quot;South&quot;, []),\n        Variant(&quot;West&quot;, []),\n      ],\n    ),\n  ),\n]\n```\n\nAPI documentation can be found at &lt;https://hexdocs.pm/glance&gt;.\n","url":"index.html"},{"doc":"glance","title":"AssignmentKind","content":"pub type AssignmentKind {\n  Let\n  Assert\n}\n\nLet\n\n\nAssert\n\n\nSynonyms:\nglance.AssignmentKind\nglance AssignmentKind","url":"glance.html#AssignmentKind"},{"doc":"glance","title":"AssignmentName","content":"pub type AssignmentName {\n  Named(String)\n  Discarded(String)\n}\n\nNamed(String)\n\n\nDiscarded(String)\n\n\nSynonyms:\nglance.AssignmentName\nglance AssignmentName","url":"glance.html#AssignmentName"},{"doc":"glance","title":"Attribute","content":"pub type Attribute {\n  Attribute(name: String, arguments: List(Expression))\n}\n\nAttribute(name: String, arguments: List(Expression))\n\n\nSynonyms:\nglance.Attribute\nglance Attribute","url":"glance.html#Attribute"},{"doc":"glance","title":"BinaryOperator","content":"pub type BinaryOperator {\n  And\n  Or\n  Eq\n  NotEq\n  LtInt\n  LtEqInt\n  LtFloat\n  LtEqFloat\n  GtEqInt\n  GtInt\n  GtEqFloat\n  GtFloat\n  Pipe\n  AddInt\n  AddFloat\n  SubInt\n  SubFloat\n  MultInt\n  MultFloat\n  DivInt\n  DivFloat\n  RemainderInt\n  Concatenate\n}\n\nAnd\n\n\nOr\n\n\nEq\n\n\nNotEq\n\n\nLtInt\n\n\nLtEqInt\n\n\nLtFloat\n\n\nLtEqFloat\n\n\nGtEqInt\n\n\nGtInt\n\n\nGtEqFloat\n\n\nGtFloat\n\n\nPipe\n\n\nAddInt\n\n\nAddFloat\n\n\nSubInt\n\n\nSubFloat\n\n\nMultInt\n\n\nMultFloat\n\n\nDivInt\n\n\nDivFloat\n\n\nRemainderInt\n\n\nConcatenate\n\n\nSynonyms:\nglance.BinaryOperator\nglance BinaryOperator","url":"glance.html#BinaryOperator"},{"doc":"glance","title":"BitStringSegmentOption","content":"pub type BitStringSegmentOption(t) {\n  BinaryOption\n  IntOption\n  FloatOption\n  BitStringOption\n  Utf8Option\n  Utf16Option\n  Utf32Option\n  Utf8CodepointOption\n  Utf16CodepointOption\n  Utf32CodepointOption\n  SignedOption\n  UnsignedOption\n  BigOption\n  LittleOption\n  NativeOption\n  SizeValueOption(t)\n  SizeOption(Int)\n  UnitOption(Int)\n}\n\nBinaryOption\n\n\nIntOption\n\n\nFloatOption\n\n\nBitStringOption\n\n\nUtf8Option\n\n\nUtf16Option\n\n\nUtf32Option\n\n\nUtf8CodepointOption\n\n\nUtf16CodepointOption\n\n\nUtf32CodepointOption\n\n\nSignedOption\n\n\nUnsignedOption\n\n\nBigOption\n\n\nLittleOption\n\n\nNativeOption\n\n\nSizeValueOption(t)\n\n\nSizeOption(Int)\n\n\nUnitOption(Int)\n\n\nSynonyms:\nglance.BitStringSegmentOption\nglance BitStringSegmentOption","url":"glance.html#BitStringSegmentOption"},{"doc":"glance","title":"Clause","content":"pub type Clause {\n  Clause(\n    patterns: List(List(Pattern)),\n    guard: Option(Expression),\n    body: Expression,\n  )\n}\n\nClause(\n  patterns: List(List(Pattern)),\n  guard: Option(Expression),\n  body: Expression,\n)\n\n\nSynonyms:\nglance.Clause\nglance Clause","url":"glance.html#Clause"},{"doc":"glance","title":"Constant","content":"pub type Constant {\n  Constant(\n    name: String,\n    publicity: Publicity,\n    annotation: Option(Type),\n    value: Expression,\n  )\n}\n\nConstant(\n  name: String,\n  publicity: Publicity,\n  annotation: Option(Type),\n  value: Expression,\n)\n\n\nSynonyms:\nglance.Constant\nglance Constant","url":"glance.html#Constant"},{"doc":"glance","title":"CustomType","content":"pub type CustomType {\n  CustomType(\n    name: String,\n    publicity: Publicity,\n    opaque_: Bool,\n    parameters: List(String),\n    variants: List(Variant),\n  )\n}\n\nCustomType(\n  name: String,\n  publicity: Publicity,\n  opaque_: Bool,\n  parameters: List(String),\n  variants: List(Variant),\n)\n\n\nSynonyms:\nglance.CustomType\nglance CustomType","url":"glance.html#CustomType"},{"doc":"glance","title":"Definition","content":"pub type Definition(definition) {\n  Definition(attributes: List(Attribute), definition)\n}\n\nDefinition(attributes: List(Attribute), definition)\n\n\nSynonyms:\nglance.Definition\nglance Definition","url":"glance.html#Definition"},{"doc":"glance","title":"Error","content":"pub type Error {\n  UnexpectedEndOfInput\n  UnexpectedToken(token: Token, position: Position)\n}\n\nUnexpectedEndOfInput\n\n\nUnexpectedToken(token: Token, position: Position)\n\n\nSynonyms:\nglance.Error\nglance Error","url":"glance.html#Error"},{"doc":"glance","title":"Expression","content":"pub type Expression {\n  Panic\n  Int(String)\n  Float(String)\n  String(String)\n  Variable(String)\n  NegateInt(Expression)\n  NegateBool(Expression)\n  Block(List(Statement))\n  Todo(Option(String))\n  Tuple(List(Expression))\n  List(elements: List(Expression), rest: Option(Expression))\n  Fn(\n    arguments: List(FnParameter),\n    return_annotation: Option(Type),\n    body: List(Statement),\n  )\n  RecordUpdate(\n    module: Option(String),\n    constructor: String,\n    record: Expression,\n    fields: List(#(String, Expression)),\n  )\n  FieldAccess(container: Expression, label: String)\n  Call(function: Expression, arguments: List(Field(Expression)))\n  TupleIndex(tuple: Expression, index: Int)\n  FnCapture(\n    function: Expression,\n    arguments_before: List(Field(Expression)),\n    arguments_after: List(Field(Expression)),\n  )\n  BitString(\n    segments: List(\n      #(Expression, List(BitStringSegmentOption(Expression))),\n    ),\n  )\n  Case(subjects: List(Expression), clauses: List(Clause))\n  BinaryOperator(\n    name: BinaryOperator,\n    left: Expression,\n    right: Expression,\n  )\n}\n\nPanic\n\n\nInt(String)\n\n\nFloat(String)\n\n\nString(String)\n\n\nVariable(String)\n\n\nNegateInt(Expression)\n\n\nNegateBool(Expression)\n\n\nBlock(List(Statement))\n\n\nTodo(Option(String))\n\n\nTuple(List(Expression))\n\n\nList(elements: List(Expression), rest: Option(Expression))\n\n\nFn(\n  arguments: List(FnParameter),\n  return_annotation: Option(Type),\n  body: List(Statement),\n)\n\n\nRecordUpdate(\n  module: Option(String),\n  constructor: String,\n  record: Expression,\n  fields: List(#(String, Expression)),\n)\n\n\nFieldAccess(container: Expression, label: String)\n\n\nCall(function: Expression, arguments: List(Field(Expression)))\n\n\nTupleIndex(tuple: Expression, index: Int)\n\n\nFnCapture(\n  function: Expression,\n  arguments_before: List(Field(Expression)),\n  arguments_after: List(Field(Expression)),\n)\n\n\nBitString(\n  segments: List(\n    #(Expression, List(BitStringSegmentOption(Expression))),\n  ),\n)\n\n\nCase(subjects: List(Expression), clauses: List(Clause))\n\n\nBinaryOperator(\n  name: BinaryOperator,\n  left: Expression,\n  right: Expression,\n)\n\n\nSynonyms:\nglance.Expression\nglance Expression","url":"glance.html#Expression"},{"doc":"glance","title":"ExternalFunction","content":"pub type ExternalFunction {\n  ExternalFunction(\n    name: String,\n    publicity: Publicity,\n    parameters: List(Field(Type)),\n    return: Type,\n    module: String,\n    function: String,\n  )\n}\n\nExternalFunction(\n  name: String,\n  publicity: Publicity,\n  parameters: List(Field(Type)),\n  return: Type,\n  module: String,\n  function: String,\n)\n\n\nSynonyms:\nglance.ExternalFunction\nglance ExternalFunction","url":"glance.html#ExternalFunction"},{"doc":"glance","title":"ExternalType","content":"pub type ExternalType {\n  ExternalType(\n    name: String,\n    publicity: Publicity,\n    parameters: List(String),\n  )\n}\n\nExternalType(\n  name: String,\n  publicity: Publicity,\n  parameters: List(String),\n)\n\n\nSynonyms:\nglance.ExternalType\nglance ExternalType","url":"glance.html#ExternalType"},{"doc":"glance","title":"Field","content":"pub type Field(t) {\n  Field(label: Option(String), item: t)\n}\n\nField(label: Option(String), item: t)\n\n\nSynonyms:\nglance.Field\nglance Field","url":"glance.html#Field"},{"doc":"glance","title":"FnParameter","content":"pub type FnParameter {\n  FnParameter(name: AssignmentName, type_: Option(Type))\n}\n\nFnParameter(name: AssignmentName, type_: Option(Type))\n\n\nSynonyms:\nglance.FnParameter\nglance FnParameter","url":"glance.html#FnParameter"},{"doc":"glance","title":"Function","content":"pub type Function {\n  Function(\n    name: String,\n    publicity: Publicity,\n    parameters: List(FunctionParameter),\n    return: Option(Type),\n    body: List(Statement),\n    location: Span,\n  )\n}\n\nFunction(\n  name: String,\n  publicity: Publicity,\n  parameters: List(FunctionParameter),\n  return: Option(Type),\n  body: List(Statement),\n  location: Span,\n)\n\n\nSynonyms:\nglance.Function\nglance Function","url":"glance.html#Function"},{"doc":"glance","title":"FunctionParameter","content":"pub type FunctionParameter {\n  FunctionParameter(\n    label: Option(String),\n    name: AssignmentName,\n    type_: Option(Type),\n  )\n}\n\nFunctionParameter(\n  label: Option(String),\n  name: AssignmentName,\n  type_: Option(Type),\n)\n\n\nSynonyms:\nglance.FunctionParameter\nglance FunctionParameter","url":"glance.html#FunctionParameter"},{"doc":"glance","title":"Import","content":"pub type Import {\n  Import(\n    module: String,\n    alias: Option(String),\n    unqualified: List(UnqualifiedImport),\n  )\n}\n\nImport(\n  module: String,\n  alias: Option(String),\n  unqualified: List(UnqualifiedImport),\n)\n\n\nSynonyms:\nglance.Import\nglance Import","url":"glance.html#Import"},{"doc":"glance","title":"Module","content":"pub type Module {\n  Module(\n    imports: List(Definition(Import)),\n    custom_types: List(Definition(CustomType)),\n    type_aliases: List(Definition(TypeAlias)),\n    constants: List(Definition(Constant)),\n    external_types: List(Definition(ExternalType)),\n    external_functions: List(Definition(ExternalFunction)),\n    functions: List(Definition(Function)),\n  )\n}\n\nModule(\n  imports: List(Definition(Import)),\n  custom_types: List(Definition(CustomType)),\n  type_aliases: List(Definition(TypeAlias)),\n  constants: List(Definition(Constant)),\n  external_types: List(Definition(ExternalType)),\n  external_functions: List(Definition(ExternalFunction)),\n  functions: List(Definition(Function)),\n)\n\n\nSynonyms:\nglance.Module\nglance Module","url":"glance.html#Module"},{"doc":"glance","title":"Pattern","content":"pub type Pattern {\n  PatternInt(value: String)\n  PatternFloat(value: String)\n  PatternString(value: String)\n  PatternDiscard(name: String)\n  PatternVariable(name: String)\n  PatternTuple(elems: List(Pattern))\n  PatternList(elements: List(Pattern), tail: Option(Pattern))\n  PatternAssignment(pattern: Pattern, name: String)\n  PatternConcatenate(left: String, right: AssignmentName)\n  PatternBitString(\n    segments: List(\n      #(Pattern, List(BitStringSegmentOption(Pattern))),\n    ),\n  )\n  PatternConstructor(\n    module: Option(String),\n    constructor: String,\n    arguments: List(Field(Pattern)),\n    with_spread: Bool,\n  )\n}\n\nPatternInt(value: String)\n\n\nPatternFloat(value: String)\n\n\nPatternString(value: String)\n\n\nPatternDiscard(name: String)\n\n\nPatternVariable(name: String)\n\n\nPatternTuple(elems: List(Pattern))\n\n\nPatternList(elements: List(Pattern), tail: Option(Pattern))\n\n\nPatternAssignment(pattern: Pattern, name: String)\n\n\nPatternConcatenate(left: String, right: AssignmentName)\n\n\nPatternBitString(\n  segments: List(\n    #(Pattern, List(BitStringSegmentOption(Pattern))),\n  ),\n)\n\n\nPatternConstructor(\n  module: Option(String),\n  constructor: String,\n  arguments: List(Field(Pattern)),\n  with_spread: Bool,\n)\n\n\nSynonyms:\nglance.Pattern\nglance Pattern","url":"glance.html#Pattern"},{"doc":"glance","title":"Publicity","content":"pub type Publicity {\n  Public\n  Private\n}\n\nPublic\n\n\nPrivate\n\n\nSynonyms:\nglance.Publicity\nglance Publicity","url":"glance.html#Publicity"},{"doc":"glance","title":"Span","content":"pub type Span {\n  Span(start: Int, end: Int)\n}\n\nSpan(start: Int, end: Int)\n A span within a file, indicated by byte offsets.\n\nSynonyms:\nglance.Span\nglance Span","url":"glance.html#Span"},{"doc":"glance","title":"Statement","content":"pub type Statement {\n  Use(patterns: List(Pattern), function: Expression)\n  Assignment(\n    kind: AssignmentKind,\n    pattern: Pattern,\n    annotation: Option(Type),\n    value: Expression,\n  )\n  Expression(Expression)\n}\n\nUse(patterns: List(Pattern), function: Expression)\n\n\nAssignment(\n  kind: AssignmentKind,\n  pattern: Pattern,\n  annotation: Option(Type),\n  value: Expression,\n)\n\n\nExpression(Expression)\n\n\nSynonyms:\nglance.Statement\nglance Statement","url":"glance.html#Statement"},{"doc":"glance","title":"Type","content":"pub type Type {\n  NamedType(\n    name: String,\n    module: Option(String),\n    parameters: List(Type),\n  )\n  TupleType(elements: List(Type))\n  FunctionType(paramters: List(Type), return: Type)\n  VariableType(name: String)\n}\n\nNamedType(\n  name: String,\n  module: Option(String),\n  parameters: List(Type),\n)\n\n\nTupleType(elements: List(Type))\n\n\nFunctionType(paramters: List(Type), return: Type)\n\n\nVariableType(name: String)\n\n\nSynonyms:\nglance.Type\nglance Type","url":"glance.html#Type"},{"doc":"glance","title":"TypeAlias","content":"pub type TypeAlias {\n  TypeAlias(\n    name: String,\n    publicity: Publicity,\n    parameters: List(String),\n    aliased: Type,\n  )\n}\n\nTypeAlias(\n  name: String,\n  publicity: Publicity,\n  parameters: List(String),\n  aliased: Type,\n)\n\n\nSynonyms:\nglance.TypeAlias\nglance TypeAlias","url":"glance.html#TypeAlias"},{"doc":"glance","title":"UnqualifiedImport","content":"pub type UnqualifiedImport {\n  UnqualifiedImport(name: String, alias: Option(String))\n}\n\nUnqualifiedImport(name: String, alias: Option(String))\n\n\nSynonyms:\nglance.UnqualifiedImport\nglance UnqualifiedImport","url":"glance.html#UnqualifiedImport"},{"doc":"glance","title":"Variant","content":"pub type Variant {\n  Variant(name: String, fields: List(Field(Type)))\n}\n\nVariant(name: String, fields: List(Field(Type)))\n\n\nSynonyms:\nglance.Variant\nglance Variant","url":"glance.html#Variant"},{"doc":"glance","title":"module","content":"pub fn module(src: String) -&gt; Result(Module, Error)\n\nSynonyms:\nglance.module\nglance module","url":"glance.html#module"},{"doc":"glance","title":"precedence","content":"pub fn precedence(operator: BinaryOperator) -&gt; Int\n\nSynonyms:\nglance.precedence\nglance precedence","url":"glance.html#precedence"},{"doc":"glance","title":"glance","content":"","url":"glance.html"}]);